@@ -12,7 +12,7 @@ def main():
     readme_path = next((path for path in github_path.iterdir() if path.stem.startswith("TEMPLATE_README")), None)
 
     if readme_path is None:
-        raise Exception("Error: A README template must be present in the base of the .github directory")
+        raise Exception(f"Error: A README template must be present in the {github_path} directory")
 
     with open(readme_path, encoding="utf-8") as readme_template:
         readme_template = readme_template.read()
